.. FConcrete documentation master file, created by
   sphinx-quickstart on Tue Jan 28 20:04:36 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to FConcrete's documentation!
=====================================


.. automodule:: fconcrete
    :members:


.. toctree::
   :maxdepth: 1
   :caption: General Information:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

.. toctree::
   :maxdepth: 3
   :caption: The module:

   Structural <fconcrete.Structural.rst>
   StructuralConcrete <fconcrete.StructuralConcrete.rst>




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
